@@ -5,13 +5,13 @@ use crate::serde_utils::{ValueDeserializer, ValueRef};
 use crate::utils;
 use nu_ansi_term::Color;
 use serde::{
-    de::value::Error as ValueError, de::Error as SerdeError, Deserialize, Deserializer, Serialize,
+    Deserialize, Deserializer, Serialize, de::Error as SerdeError, de::value::Error as ValueError,
 };
 
 use std::borrow::Cow;
 use std::clone::Clone;
 use std::collections::HashMap;
-use std::ffi::OsString;
+use std::ffi::OsStr;
 use std::io::ErrorKind;
 
 use toml::Value;
@@ -32,13 +32,13 @@ where
         match Self::from_config(config) {
             Ok(config) => config,
             Err(e) => {
-                log::warn!("Failed to load config value: {}", e);
+                log::warn!("Failed to load config value: {e}");
                 Self::default()
             }
         }
     }
 
-    /// Helper function that will call `ModuleConfig::from_config(config)  if config is Some,
+    /// Helper function that will call `ModuleConfig::from_config(config)` if config is Some,
     /// or `ModuleConfig::default()` if config is None.
     fn try_load<V: Into<ValueRef<'a>>>(config: Option<V>) -> Self {
         config.map(Into::into).map(Self::load).unwrap_or_default()
@@ -54,7 +54,7 @@ impl<'a, T: Deserialize<'a> + Default> ModuleConfig<'a, ValueError> for T {
             // If the error is an unrecognized key, print a warning and run
             // deserialize ignoring that error. Otherwise, just return the error
             if err.to_string().contains("Unknown key") {
-                log::warn!("{}", err);
+                log::warn!("{err}");
                 let deserializer2 = ValueDeserializer::new(config).with_allow_unknown_keys();
                 T::deserialize(deserializer2)
             } else {
@@ -102,16 +102,17 @@ impl<T> schemars::JsonSchema for VecOr<T>
 where
     T: schemars::JsonSchema + Sized,
 {
-    fn schema_name() -> String {
+    fn schema_name() -> Cow<'static, str> {
         Either::<T, Vec<T>>::schema_name()
     }
 
-    fn json_schema(gen: &mut schemars::gen::SchemaGenerator) -> schemars::schema::Schema {
-        Either::<T, Vec<T>>::json_schema(gen)
+    fn schema_id() -> Cow<'static, str> {
+        let mod_path = module_path!();
+        Cow::Owned(format!("{mod_path}::{}", Self::schema_name()))
     }
 
-    fn is_referenceable() -> bool {
-        Either::<T, Vec<T>>::is_referenceable()
+    fn json_schema(generator: &mut schemars::generate::SchemaGenerator) -> schemars::Schema {
+        Either::<T, Vec<T>>::json_schema(generator)
     }
 }
 
@@ -123,7 +124,7 @@ pub struct StarshipConfig {
 
 impl StarshipConfig {
     /// Initialize the Config struct
-    pub fn initialize(config_file_path: &Option<OsString>) -> Self {
+    pub fn initialize(config_file_path: Option<&OsStr>) -> Self {
         Self::config_from_file(config_file_path)
             .map(|config| Self {
                 config: Some(config),
@@ -132,7 +133,7 @@ impl StarshipConfig {
     }
 
     /// Create a config from a starship configuration file
-    fn config_from_file(config_file_path: &Option<OsString>) -> Option<toml::Table> {
+    fn config_from_file(config_file_path: Option<&OsStr>) -> Option<toml::Table> {
         let toml_content = Self::read_config_content_as_str(config_file_path)?;
 
         match toml::from_str(&toml_content) {
@@ -141,13 +142,13 @@ impl StarshipConfig {
                 Some(parsed)
             }
             Err(error) => {
-                log::error!("Unable to parse the config file: {}", error);
+                log::error!("Unable to parse the config file: {error}");
                 None
             }
         }
     }
 
-    pub fn read_config_content_as_str(config_file_path: &Option<OsString>) -> Option<String> {
+    pub fn read_config_content_as_str(config_file_path: Option<&OsStr>) -> Option<String> {
         if config_file_path.is_none() {
             log::debug!(
                 "Unable to determine `config_file_path`. Perhaps `utils::home_dir` is not defined on your platform?"
@@ -200,28 +201,24 @@ impl StarshipConfig {
 
         // Assumes all keys except the last in path has a table
         for option in table_options {
-            match prev_table.get(*option) {
-                Some(value) => match value.as_table() {
-                    Some(value) => {
-                        prev_table = value;
-                    }
-                    None => {
-                        log::trace!(
-                            "No config found for \"{}\": \"{}\" is not a table",
-                            path.join("."),
-                            &option
-                        );
-                        return None;
-                    }
-                },
-                None => {
+            if let Some(value) = prev_table.get(*option) {
+                if let Some(value) = value.as_table() {
+                    prev_table = value;
+                } else {
                     log::trace!(
-                        "No config found for \"{}\": Option \"{}\" not found",
+                        "No config found for \"{}\": \"{}\" is not a table",
                         path.join("."),
                         &option
                     );
                     return None;
                 }
+            } else if prev_table.contains_key(*option) {
+                log::trace!(
+                    "No config found for \"{}\": \"{}\" is not a table",
+                    path.join("."),
+                    &option
+                );
+                return None;
             }
         }
 
@@ -233,7 +230,7 @@ impl StarshipConfig {
                 path.join("."),
                 &last_option
             );
-        };
+        }
         value
     }
 
@@ -261,7 +258,7 @@ impl StarshipConfig {
 }
 
 /// Deserialize a style string in the starship format with serde
-pub fn deserialize_style<'de, D>(de: D) -> Result<nu_ansi_term::Style, D::Error>
+pub fn deserialize_style<'de, D>(de: D) -> Result<Style, D::Error>
 where
     D: Deserializer<'de>,
 {
@@ -270,6 +267,88 @@ where
     })
 }
 
+#[derive(Clone, Copy, Debug, PartialEq)]
+enum PrevColor {
+    Fg,
+    Bg,
+}
+
+#[derive(Clone, Copy, Debug, Default, PartialEq)]
+/// Wrapper for `nu_ansi_term::Style` that supports referencing the previous style's foreground/background color.
+pub struct Style {
+    style: nu_ansi_term::Style,
+    bg: Option<PrevColor>,
+    fg: Option<PrevColor>,
+}
+
+impl Style {
+    pub fn to_ansi_style(&self, prev: Option<&nu_ansi_term::Style>) -> nu_ansi_term::Style {
+        let Some(prev_style) = prev else {
+            return self.style;
+        };
+
+        let mut current = self.style;
+
+        if let Some(prev_color) = self.bg {
+            match prev_color {
+                PrevColor::Fg => current.background = prev_style.foreground,
+                PrevColor::Bg => current.background = prev_style.background,
+            }
+        }
+
+        if let Some(prev_color) = self.fg {
+            match prev_color {
+                PrevColor::Fg => current.foreground = prev_style.foreground,
+                PrevColor::Bg => current.foreground = prev_style.background,
+            }
+        }
+
+        current
+    }
+
+    fn map_style<F>(&self, f: F) -> Self
+    where
+        F: FnOnce(&nu_ansi_term::Style) -> nu_ansi_term::Style,
+    {
+        Self {
+            style: f(&self.style),
+            ..*self
+        }
+    }
+
+    fn fg(&self, prev_color: PrevColor) -> Self {
+        Self {
+            fg: Some(prev_color),
+            ..*self
+        }
+    }
+
+    fn bg(&self, prev_color: PrevColor) -> Self {
+        Self {
+            bg: Some(prev_color),
+            ..*self
+        }
+    }
+}
+
+impl From<nu_ansi_term::Style> for Style {
+    fn from(value: nu_ansi_term::Style) -> Self {
+        Self {
+            style: value,
+            ..Default::default()
+        }
+    }
+}
+
+impl From<nu_ansi_term::Color> for Style {
+    fn from(value: nu_ansi_term::Color) -> Self {
+        Self {
+            style: value.into(),
+            ..Default::default()
+        }
+    }
+}
+
 /** Parse a style string which represents an ansi style. Valid tokens in the style
  string include the following:
  - 'fg:<color>'    (specifies that the color read should be a foreground color)
@@ -279,15 +358,14 @@ where
  - 'italic'
  - 'inverted'
  - 'blink'
+ - '`prev_fg`'        (specifies the color should be the previous foreground color)
+ - '`prev_bg`'        (specifies the color should be the previous background color)
  - '<color>'       (see the `parse_color_string` doc for valid color strings)
 */
-pub fn parse_style_string(
-    style_string: &str,
-    context: Option<&Context>,
-) -> Option<nu_ansi_term::Style> {
+pub fn parse_style_string(style_string: &str, context: Option<&Context>) -> Option<Style> {
     style_string
         .split_whitespace()
-        .try_fold(nu_ansi_term::Style::new(), |style, token| {
+        .try_fold(Style::default(), |style, token| {
             let token = token.to_lowercase();
 
             // Check for FG/BG identifiers and strip them off if appropriate
@@ -301,14 +379,21 @@ pub fn parse_style_string(
             };
 
             match token.as_str() {
-                "underline" => Some(style.underline()),
-                "bold" => Some(style.bold()),
-                "italic" => Some(style.italic()),
-                "dimmed" => Some(style.dimmed()),
-                "inverted" => Some(style.reverse()),
-                "blink" => Some(style.blink()),
-                "hidden" => Some(style.hidden()),
-                "strikethrough" => Some(style.strikethrough()),
+                "underline" => Some(style.map_style(nu_ansi_term::Style::underline)),
+                "bold" => Some(style.map_style(nu_ansi_term::Style::bold)),
+                "italic" => Some(style.map_style(nu_ansi_term::Style::italic)),
+                "dimmed" => Some(style.map_style(nu_ansi_term::Style::dimmed)),
+                "inverted" => Some(style.map_style(nu_ansi_term::Style::reverse)),
+                "blink" => Some(style.map_style(nu_ansi_term::Style::blink)),
+                "hidden" => Some(style.map_style(nu_ansi_term::Style::hidden)),
+                "strikethrough" => Some(style.map_style(nu_ansi_term::Style::strikethrough)),
+
+                "prev_fg" if col_fg => Some(style.fg(PrevColor::Fg)),
+                "prev_fg" => Some(style.bg(PrevColor::Fg)),
+
+                "prev_bg" if col_fg => Some(style.fg(PrevColor::Bg)),
+                "prev_bg" => Some(style.bg(PrevColor::Bg)),
+
                 // When the string is supposed to be a color:
                 // Decide if we yield none, reset background or set color.
                 color_string => {
@@ -328,15 +413,15 @@ pub fn parse_style_string(
                         // bg + invalid color = reset the background to default.
                         if !col_fg && parsed.is_none() {
                             let mut new_style = style;
-                            new_style.background = Option::None;
+                            new_style.style.background = Option::None;
                             Some(new_style)
                         } else {
                             // Valid color, apply color to either bg or fg
                             parsed.map(|ansi_color| {
                                 if col_fg {
-                                    style.fg(ansi_color)
+                                    style.map_style(|s| s.fg(ansi_color))
                                 } else {
-                                    style.on(ansi_color)
+                                    style.map_style(|s| s.on(ansi_color))
                                 }
                             })
                         }
@@ -357,36 +442,29 @@ fn parse_color_string(
     palette: Option<&Palette>,
 ) -> Option<nu_ansi_term::Color> {
     // Parse RGB hex values
-    log::trace!("Parsing color_string: {}", color_string);
+    log::trace!("Parsing color_string: {color_string}");
     if color_string.starts_with('#') {
-        log::trace!(
-            "Attempting to read hexadecimal color string: {}",
-            color_string
-        );
+        log::trace!("Attempting to read hexadecimal color string: {color_string}");
         if color_string.len() != 7 {
-            log::debug!("Could not parse hexadecimal string: {}", color_string);
+            log::debug!("Could not parse hexadecimal string: {color_string}");
             return None;
         }
         let r: u8 = u8::from_str_radix(&color_string[1..3], 16).ok()?;
         let g: u8 = u8::from_str_radix(&color_string[3..5], 16).ok()?;
         let b: u8 = u8::from_str_radix(&color_string[5..7], 16).ok()?;
-        log::trace!("Read RGB color string: {},{},{}", r, g, b);
+        log::trace!("Read RGB color string: {r},{g},{b}");
         return Some(Color::Rgb(r, g, b));
     }
 
     // Parse a u8 (ansi color)
     if let Result::Ok(ansi_color_num) = color_string.parse::<u8>() {
-        log::trace!("Read ANSI color string: {}", ansi_color_num);
+        log::trace!("Read ANSI color string: {ansi_color_num}");
         return Some(Color::Fixed(ansi_color_num));
     }
 
     // Check palette for a matching user-defined color
     if let Some(palette_color) = palette.as_ref().and_then(|x| x.get(color_string)) {
-        log::trace!(
-            "Read user-defined color string: {} defined as {}",
-            color_string,
-            palette_color
-        );
+        log::trace!("Read user-defined color string: {color_string} defined as {palette_color}");
         return parse_color_string(palette_color, None);
     }
 
@@ -413,9 +491,9 @@ fn parse_color_string(
     };
 
     if predefined_color.is_some() {
-        log::trace!("Read predefined color: {}", color_string);
+        log::trace!("Read predefined color: {color_string}");
     } else {
-        log::debug!("Could not parse color in string: {}", color_string);
+        log::debug!("Could not parse color in string: {color_string}");
     }
     predefined_color
 }
@@ -427,9 +505,9 @@ fn get_palette<'a>(
     if let Some(palette_name) = palette_name {
         let palette = palettes.get(palette_name);
         if palette.is_some() {
-            log::trace!("Found color palette: {}", palette_name);
+            log::trace!("Found color palette: {palette_name}");
         } else {
-            log::warn!("Could not find color palette: {}", palette_name);
+            log::warn!("Could not find color palette: {palette_name}");
         }
         palette
     } else {
@@ -441,7 +519,7 @@ fn get_palette<'a>(
 #[cfg(test)]
 mod tests {
     use super::*;
-    use nu_ansi_term::Style;
+    use nu_ansi_term::Style as AnsiStyle;
 
     // Small wrapper to allow deserializing Style without a struct with #[serde(deserialize_with=)]
     #[derive(Default, Clone, Debug, PartialEq)]
@@ -514,7 +592,7 @@ mod tests {
             git_status_config.modified,
             SegmentDisplayConfig {
                 value: "∙",
-                style: Color::Red.normal(),
+                style: Color::Red.normal().into(),
             }
         );
     }
@@ -547,9 +625,10 @@ mod tests {
             pub switch_c: Switch,
         }
 
-        #[derive(Debug, PartialEq, Clone)]
+        #[derive(Debug, PartialEq, Clone, Default)]
         enum Switch {
             On,
+            #[default]
             Off,
         }
 
@@ -566,12 +645,6 @@ mod tests {
             }
         }
 
-        impl Default for Switch {
-            fn default() -> Self {
-                Self::Off
-            }
-        }
-
         let config = toml::toml! {
             switch_a = "on"
             switch_b = "any"
@@ -624,7 +697,7 @@ mod tests {
         let config = Value::from("red bold");
         assert_eq!(
             <StyleWrapper>::from_config(&config).unwrap().0,
-            Color::Red.bold()
+            Color::Red.bold().into()
         );
     }
 
@@ -662,13 +735,13 @@ mod tests {
     fn table_get_styles_bold_italic_underline_green_dimmed_silly_caps() {
         let config = Value::from("bOlD ItAlIc uNdErLiNe GrEeN diMMeD");
         let mystyle = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert!(mystyle.is_bold);
-        assert!(mystyle.is_italic);
-        assert!(mystyle.is_underline);
-        assert!(mystyle.is_dimmed);
+        assert!(mystyle.to_ansi_style(None).is_bold);
+        assert!(mystyle.to_ansi_style(None).is_italic);
+        assert!(mystyle.to_ansi_style(None).is_underline);
+        assert!(mystyle.to_ansi_style(None).is_dimmed);
         assert_eq!(
-            mystyle,
-            nu_ansi_term::Style::new()
+            mystyle.to_ansi_style(None),
+            AnsiStyle::new()
                 .bold()
                 .italic()
                 .underline()
@@ -681,14 +754,14 @@ mod tests {
     fn table_get_styles_bold_italic_underline_green_dimmed_inverted_silly_caps() {
         let config = Value::from("bOlD ItAlIc uNdErLiNe GrEeN diMMeD InVeRTed");
         let mystyle = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert!(mystyle.is_bold);
-        assert!(mystyle.is_italic);
-        assert!(mystyle.is_underline);
-        assert!(mystyle.is_dimmed);
-        assert!(mystyle.is_reverse);
+        assert!(mystyle.to_ansi_style(None).is_bold);
+        assert!(mystyle.to_ansi_style(None).is_italic);
+        assert!(mystyle.to_ansi_style(None).is_underline);
+        assert!(mystyle.to_ansi_style(None).is_dimmed);
+        assert!(mystyle.to_ansi_style(None).is_reverse);
         assert_eq!(
-            mystyle,
-            nu_ansi_term::Style::new()
+            mystyle.to_ansi_style(None),
+            AnsiStyle::new()
                 .bold()
                 .italic()
                 .underline()
@@ -702,14 +775,14 @@ mod tests {
     fn table_get_styles_bold_italic_underline_green_dimmed_blink_silly_caps() {
         let config = Value::from("bOlD ItAlIc uNdErLiNe GrEeN diMMeD bLiNk");
         let mystyle = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert!(mystyle.is_bold);
-        assert!(mystyle.is_italic);
-        assert!(mystyle.is_underline);
-        assert!(mystyle.is_dimmed);
-        assert!(mystyle.is_blink);
+        assert!(mystyle.to_ansi_style(None).is_bold);
+        assert!(mystyle.to_ansi_style(None).is_italic);
+        assert!(mystyle.to_ansi_style(None).is_underline);
+        assert!(mystyle.to_ansi_style(None).is_dimmed);
+        assert!(mystyle.to_ansi_style(None).is_blink);
         assert_eq!(
-            mystyle,
-            nu_ansi_term::Style::new()
+            mystyle.to_ansi_style(None),
+            AnsiStyle::new()
                 .bold()
                 .italic()
                 .underline()
@@ -723,14 +796,14 @@ mod tests {
     fn table_get_styles_bold_italic_underline_green_dimmed_hidden_silly_caps() {
         let config = Value::from("bOlD ItAlIc uNdErLiNe GrEeN diMMeD hIDDen");
         let mystyle = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert!(mystyle.is_bold);
-        assert!(mystyle.is_italic);
-        assert!(mystyle.is_underline);
-        assert!(mystyle.is_dimmed);
-        assert!(mystyle.is_hidden);
+        assert!(mystyle.to_ansi_style(None).is_bold);
+        assert!(mystyle.to_ansi_style(None).is_italic);
+        assert!(mystyle.to_ansi_style(None).is_underline);
+        assert!(mystyle.to_ansi_style(None).is_dimmed);
+        assert!(mystyle.to_ansi_style(None).is_hidden);
         assert_eq!(
-            mystyle,
-            nu_ansi_term::Style::new()
+            mystyle.to_ansi_style(None),
+            AnsiStyle::new()
                 .bold()
                 .italic()
                 .underline()
@@ -744,14 +817,14 @@ mod tests {
     fn table_get_styles_bold_italic_underline_green_dimmed_strikethrough_silly_caps() {
         let config = Value::from("bOlD ItAlIc uNdErLiNe GrEeN diMMeD StRiKEthROUgh");
         let mystyle = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert!(mystyle.is_bold);
-        assert!(mystyle.is_italic);
-        assert!(mystyle.is_underline);
-        assert!(mystyle.is_dimmed);
-        assert!(mystyle.is_strikethrough);
+        assert!(mystyle.to_ansi_style(None).is_bold);
+        assert!(mystyle.to_ansi_style(None).is_italic);
+        assert!(mystyle.to_ansi_style(None).is_underline);
+        assert!(mystyle.to_ansi_style(None).is_dimmed);
+        assert!(mystyle.to_ansi_style(None).is_strikethrough);
         assert_eq!(
-            mystyle,
-            nu_ansi_term::Style::new()
+            mystyle.to_ansi_style(None),
+            AnsiStyle::new()
                 .bold()
                 .italic()
                 .underline()
@@ -766,7 +839,7 @@ mod tests {
         // Test a "plain" style with no formatting
         let config = Value::from("");
         let plain_style = <StyleWrapper>::from_config(&config).unwrap().0;
-        assert_eq!(plain_style, nu_ansi_term::Style::new());
+        assert_eq!(plain_style.to_ansi_style(None), AnsiStyle::new());
 
         // Test a string that's clearly broken
         let config = Value::from("djklgfhjkldhlhk;j");
@@ -803,21 +876,84 @@ mod tests {
         let config = Value::from("fg:red bg:none");
         assert_eq!(
             <StyleWrapper>::from_config(&config).unwrap().0,
-            Color::Red.normal()
+            Color::Red.normal().into()
         );
 
         // Test that bg:none will yield a style
         let config = Value::from("fg:red bg:none bold");
         assert_eq!(
             <StyleWrapper>::from_config(&config).unwrap().0,
-            Color::Red.bold()
+            Color::Red.bold().into()
         );
 
         // Test that bg:none will overwrite the previous background colour
         let config = Value::from("fg:red bg:green bold bg:none");
         assert_eq!(
             <StyleWrapper>::from_config(&config).unwrap().0,
-            Color::Red.bold()
+            Color::Red.bold().into()
+        );
+    }
+
+    #[test]
+    fn table_get_styles_previous() {
+        // Test that previous has no effect when there is no previous style
+        let both_prevfg = <StyleWrapper>::from_config(&Value::from(
+            "bold fg:black fg:prev_bg bg:prev_fg underline",
+        ))
+        .unwrap()
+        .0;
+
+        assert_eq!(
+            both_prevfg.to_ansi_style(None),
+            AnsiStyle::default().fg(Color::Black).bold().underline()
+        );
+
+        // But if there is a style on the previous string, then use that
+        let prev_style = AnsiStyle::new()
+            .underline()
+            .fg(Color::Yellow)
+            .on(Color::Red);
+
+        assert_eq!(
+            both_prevfg.to_ansi_style(Some(&prev_style)),
+            AnsiStyle::new()
+                .fg(Color::Red)
+                .on(Color::Yellow)
+                .bold()
+                .underline()
+        );
+
+        // Test that all the combinations of previous colors work
+        let fg_prev_fg = <StyleWrapper>::from_config(&Value::from("fg:prev_fg"))
+            .unwrap()
+            .0;
+        assert_eq!(
+            fg_prev_fg.to_ansi_style(Some(&prev_style)),
+            AnsiStyle::new().fg(Color::Yellow)
+        );
+
+        let fg_prev_bg = <StyleWrapper>::from_config(&Value::from("fg:prev_bg"))
+            .unwrap()
+            .0;
+        assert_eq!(
+            fg_prev_bg.to_ansi_style(Some(&prev_style)),
+            AnsiStyle::new().fg(Color::Red)
+        );
+
+        let bg_prev_fg = <StyleWrapper>::from_config(&Value::from("bg:prev_fg"))
+            .unwrap()
+            .0;
+        assert_eq!(
+            bg_prev_fg.to_ansi_style(Some(&prev_style)),
+            AnsiStyle::new().on(Color::Yellow)
+        );
+
+        let bg_prev_bg = <StyleWrapper>::from_config(&Value::from("bg:prev_bg"))
+            .unwrap()
+            .0;
+        assert_eq!(
+            bg_prev_bg.to_ansi_style(Some(&prev_style)),
+            AnsiStyle::new().on(Color::Red)
         );
     }
 
@@ -827,8 +963,8 @@ mod tests {
         let config = Value::from("bg:#050505 underline fg:120");
         let flipped_style = <StyleWrapper>::from_config(&config).unwrap().0;
         assert_eq!(
-            flipped_style,
-            Style::new()
+            flipped_style.to_ansi_style(None),
+            AnsiStyle::new()
                 .underline()
                 .fg(Color::Fixed(120))
                 .on(Color::Rgb(5, 5, 5))
@@ -838,8 +974,8 @@ mod tests {
         let config = Value::from("bg:120 bg:125 bg:127 fg:127 122 125");
         let multi_style = <StyleWrapper>::from_config(&config).unwrap().0;
         assert_eq!(
-            multi_style,
-            Style::new().fg(Color::Fixed(125)).on(Color::Fixed(127))
+            multi_style.to_ansi_style(None),
+            AnsiStyle::new().fg(Color::Fixed(125)).on(Color::Fixed(127))
         );
     }
 
@@ -876,7 +1012,7 @@ mod tests {
         assert_eq!(
             parse_color_string("green", Some(&palette)),
             Some(Color::Green)
-        )
+        );
     }
 
     #[test]
@@ -919,7 +1055,7 @@ mod tests {
     fn read_config_no_config_file_path_provided() {
         assert_eq!(
             None,
-            StarshipConfig::read_config_content_as_str(&None),
+            StarshipConfig::read_config_content_as_str(None),
             "if the platform doesn't have utils::home_dir(), it should return None"
         );
     }
