@@ -18,9 +18,9 @@ pub struct GitCommitConfig<'a> {
     pub tag_max_candidates: usize,
 }
 
-impl<'a> Default for GitCommitConfig<'a> {
+impl Default for GitCommitConfig<'_> {
     fn default() -> Self {
-        GitCommitConfig {
+        Self {
             // be consistent with git by default, which has DEFAULT_ABBREV set to 7
             commit_hash_length: 7,
             format: "[\\($hash$tag\\)]($style) ",
