@@ -18,9 +18,9 @@ pub struct JuliaConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for JuliaConfig<'a> {
+impl Default for JuliaConfig<'_> {
     fn default() -> Self {
-        JuliaConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             symbol: "ஃ ",
