@@ -14,9 +14,9 @@ pub struct OspConfig<'a> {
     pub disabled: bool,
 }
 
-impl<'a> Default for OspConfig<'a> {
+impl Default for OspConfig<'_> {
     fn default() -> Self {
-        OspConfig {
+        Self {
             format: "on [$symbol$cloud(\\($project\\))]($style) ",
             symbol: "☁️  ",
             style: "bold yellow",
