@@ -18,9 +18,9 @@ pub struct RLangConfig<'a> {
     pub detect_folders: Vec<&'a str>,
 }
 
-impl<'a> Default for RLangConfig<'a> {
+impl Default for RLangConfig<'_> {
     fn default() -> Self {
-        RLangConfig {
+        Self {
             format: "via [$symbol($version )]($style)",
             version_format: "v${raw}",
             style: "blue bold",
