@@ -48,6 +48,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "git_metrics",
     "git_status",
     "hg_branch",
+    "hg_state",
     "pijul_channel",
     "docker_context",
     "package",
@@ -66,6 +67,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "elm",
     "erlang",
     "fennel",
+    "fortran",
     "gleam",
     "golang",
     "gradle",
@@ -100,6 +102,7 @@ pub const PROMPT_ORDER: &[&str] = &[
     "typst",
     "vlang",
     "vagrant",
+    "xmake",
     "zig",
     // ↑ Toolchain version modules ↑
     "buf",
