@@ -20,7 +20,7 @@ pub struct UsernameConfig<'a> {
 
 impl Default for UsernameConfig<'_> {
     fn default() -> Self {
-        UsernameConfig {
+        Self {
             detect_env_vars: vec![],
             format: "[$user]($style) in ",
             style_root: "red bold",
