@@ -10,7 +10,7 @@ use clap_complete::generate;
 use rand::Rng;
 use starship::context::{Context, Properties, Target};
 use starship::module::ALL_MODULES;
-use starship::*;
+use starship::{bug_report, configure, init, logger, num_rayon_threads, print, shadow};
 
 #[derive(Parser, Debug)]
 #[clap(
@@ -26,12 +26,13 @@ struct Cli {
     command: Commands,
 }
 
-#[derive(clap::Parser, ValueEnum, Debug, Clone, PartialEq, Eq)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, ValueEnum)]
 enum CompletionShell {
     Bash,
     Elvish,
     Fish,
     Nushell,
+    #[clap(name = "powershell", alias = "pwsh", alias = "power-shell")]
     PowerShell,
     Zsh,
 }
@@ -42,7 +43,7 @@ fn generate_shell(shell: impl clap_complete::Generator) {
         &mut Cli::command(),
         "starship",
         &mut io::stdout().lock(),
-    )
+    );
 }
 
 fn generate_completions(shell: CompletionShell) {
@@ -173,10 +174,11 @@ fn main() {
             let exit_code = if is_info_only {
                 0
             } else {
+                use io::Write;
+
                 // print the arguments
                 // avoid panicking in case of stderr closing
                 let mut stderr = io::stderr();
-                use io::Write;
                 let _ = writeln!(
                     stderr,
                     "\nNOTE:\n    passed arguments: {:?}",
@@ -191,7 +193,7 @@ fn main() {
             std::process::exit(exit_code);
         }
     };
-    log::trace!("Parsed arguments: {:#?}", args);
+    log::trace!("Parsed arguments: {args:#?}");
 
     match args.command {
         Commands::Init {
