@@ -48,7 +48,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `deno`:\n{}", error);
+            log::warn!("Error in module `deno`:\n{error}");
             return None;
         }
     });
@@ -70,7 +70,7 @@ fn parse_deno_version(deno_version: &str) -> Option<String> {
 #[cfg(test)]
 mod tests {
     use crate::test::ModuleRenderer;
-    use ansi_term::Color;
+    use nu_ansi_term::Color;
     use std::fs::File;
     use std::io;
 
@@ -103,6 +103,16 @@ mod tests {
         dir.close()
     }
 
+    #[test]
+    fn folder_with_deno_lock() -> io::Result<()> {
+        let dir = tempfile::tempdir()?;
+        File::create(dir.path().join("deno.lock"))?.sync_all()?;
+        let actual = ModuleRenderer::new("deno").path(dir.path()).collect();
+        let expected = Some(format!("via {}", Color::Green.bold().paint("🦕 v1.8.3 ")));
+        assert_eq!(expected, actual);
+        dir.close()
+    }
+
     #[test]
     fn folder_with_mod_ts() -> io::Result<()> {
         let dir = tempfile::tempdir()?;
