@@ -28,14 +28,10 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
         .inspect_err(|e| log::warn!("Failed to get hostname: {e}"))
         .ok()?;
 
-    //rustc doesn't let you do an "if" and an "if let" in the same if statement
-    // if this changes in the future this can become a lot cleaner
-    let mut host = if !config.trim_at.is_empty() {
-        if let Some(index) = host.find(config.trim_at) {
-            host.split_at(index).0
-        } else {
-            host.as_ref()
-        }
+    let mut host = if !config.trim_at.is_empty()
+        && let Some(index) = host.find(config.trim_at)
+    {
+        host.split_at(index).0
     } else {
         host.as_ref()
     };
@@ -70,7 +66,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `hostname`:\n{}", error);
+            log::warn!("Error in module `hostname`:\n{error}");
             return None;
         }
     });
