@@ -1,4 +1,4 @@
-use yaml_rust::YamlLoader;
+use yaml_rust2::YamlLoader;
 
 use super::{Context, Module, ModuleConfig};
 
@@ -75,7 +75,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::error!("Error in module `openstack`: \n{}", error);
+            log::error!("Error in module `openstack`: \n{error}");
             return None;
         }
     });
