@@ -12,14 +12,12 @@ pub fn truncate_text(text: &str, length: usize, truncation_symbol: &str) -> Stri
 
     let truncated_graphemes = get_graphemes(text, length);
     // The truncation symbol should only be added if we truncated
-    let truncated_and_symbol = if length < graphemes_len(text) {
+    if length < graphemes_len(text) {
         let truncation_symbol = get_graphemes(truncation_symbol, 1);
         truncated_graphemes + truncation_symbol.as_str()
     } else {
         truncated_graphemes
-    };
-
-    truncated_and_symbol
+    }
 }
 
 fn get_graphemes(text: &str, length: usize) -> String {
@@ -46,52 +44,52 @@ mod tests {
 
     #[test]
     fn test_changed_truncation_symbol() {
-        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "%")
+        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "%");
     }
 
     #[test]
     fn test_no_truncation_symbol() {
-        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "")
+        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "");
     }
 
     #[test]
     fn test_ascii_boundary_below() {
-        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "…")
+        test_truncate_length("1337_hello_world", 15, "1337_hello_worl", "…");
     }
 
     #[test]
     fn test_ascii_boundary_on() {
-        test_truncate_length("1337_hello_world", 16, "1337_hello_world", "")
+        test_truncate_length("1337_hello_world", 16, "1337_hello_world", "");
     }
 
     #[test]
     fn test_ascii_boundary_above() {
-        test_truncate_length("1337_hello_world", 17, "1337_hello_world", "")
+        test_truncate_length("1337_hello_world", 17, "1337_hello_world", "");
     }
 
     #[test]
     fn test_one() {
-        test_truncate_length("1337_hello_world", 1, "1", "…")
+        test_truncate_length("1337_hello_world", 1, "1", "…");
     }
 
     #[test]
     fn test_negative() {
-        test_truncate_length("1337_hello_world", -1, "1337_hello_world", "")
+        test_truncate_length("1337_hello_world", -1, "1337_hello_world", "");
     }
 
     #[test]
     fn test_hindi_truncation() {
-        test_truncate_length("नमस्ते", 3, "नमस्", "…")
+        test_truncate_length("नमस्ते", 2, "नम", "…");
     }
 
     #[test]
     fn test_hindi_truncation2() {
-        test_truncate_length("नमस्त", 3, "नमस्", "…")
+        test_truncate_length("नमस्त", 2, "नम", "…");
     }
 
     #[test]
     fn test_japanese_truncation() {
-        test_truncate_length("がんばってね", 4, "がんばっ", "…")
+        test_truncate_length("がんばってね", 4, "がんばっ", "…");
     }
 
     fn test_truncate_length(
