@@ -48,7 +48,7 @@ pub fn module<'a>(context: &'a Context) -> Option<Module<'a>> {
     module.set_segments(match parsed {
         Ok(segments) => segments,
         Err(error) => {
-            log::warn!("Error in module `vlang`:\n{}", error);
+            log::warn!("Error in module `vlang`:\n{error}");
             return None;
         }
     });
@@ -70,14 +70,14 @@ fn parse_v_version(v_version: &str) -> Option<String> {
 mod tests {
     use super::parse_v_version;
     use crate::test::ModuleRenderer;
-    use ansi_term::Color;
+    use nu_ansi_term::Color;
     use std::fs::File;
     use std::io;
 
     #[test]
     fn test_parse_v_version() {
         const OUTPUT: &str = "V 0.2 30c0659\n";
-        assert_eq!(parse_v_version(OUTPUT), Some("0.2".to_string()))
+        assert_eq!(parse_v_version(OUTPUT), Some("0.2".to_string()));
     }
 
     #[test]
